=================
pysmatch docs
=================

**pysmatch** provides propensity score matching workflows for observational studies,
including score modeling, flexible matching strategies, and balance diagnostics.

.. toctree::
   :maxdepth: 1
   :caption: Start Here

   generated/installation_en
   generated/quickstart_en
   generated/workflow_en

.. toctree::
   :maxdepth: 1
   :caption: Guides

   generated/matching_en
   generated/evaluation_en
   generated/troubleshooting_en
   generated/faq_en

.. toctree::
   :maxdepth: 1
   :caption: Chinese Entry

   generated/installation_zh
   generated/quickstart_zh
   generated/workflow_zh
   generated/matching_zh
   generated/evaluation_zh
   generated/troubleshooting_zh
   generated/faq_zh

.. toctree::
   :maxdepth: 1
   :caption: README Mirrors

   readme_en
   readme_zh

.. toctree::
   :maxdepth: 1
   :caption: API & Project

   api
   contributing
   changelog

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Legacy Pages

   installation
   usage
   example

.. only:: html

   .. rubric:: Quick Navigation

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
